/* Preload loading svg animation */
loading = new Image();
loading.src = "../img/loading.svg";

/* 
 * buildElement () is used to build the UI for
 * Open in Livestreamer
 */
function buildElement (data) {
    if (data.type != null) {
        type = data.type;
    } else {
        type = "div"
    }
    element = document.createElement(type);
    if (data.empty == true && data.append != null) {
        element.innerHTML = "";
        while (data.append.firstChild){
            data.append.removeChild (data.append.firstChild);
        }
    }
    if (data.attribs != null && data.attribs != "") {
        for (var key in data.attribs) {
            if (data.attribs.hasOwnProperty(key)) {
                if (key == "class") {
                    if (data.attribs[key] instanceof Array) {
                        for (var i = 0; i < data.attribs[key].length; i++) {
                            element.classList.add (data.attribs[key][i]);
                        }
                    } else {
                        element.classList.add (data.attribs[key]);
                    }
                } else if (key == "dataset") {
                    for (var subkey in data.attribs[key]) {
                        if (data.attribs[key].hasOwnProperty(subkey)) {
                            element.dataset[subkey] = data.attribs[key][subkey];
                        }
                    }
                } else {
                    element[key] = data.attribs[key];
                }
            }
        }
    }
    if (typeof data.content == "object") {
        if (data.content instanceof Array) {
            for (var i = 0; i < data.content.length; i++) {
                element.appendChild (data.content[i]);
            }
        } else {
            element.appendChild (data.content);
        }
    } else {
        element.innerHTML = data.content;
    }
    if (data.append != null) {
        data.append.appendChild (element);
    } else {
        return element;
    }
}
function updateElement (selector, data) {
    var element = document.querySelectorAll (selector);
    for (var i = 0; i < element.length; i++) {
        element[i].innerHTML = data.content;
    }
}
function launchStreamer (e) {
    console.log ("Quality setting: " + e.target.dataset.quality);
    launchStreamerUI (e);
}
function launchStreamerUI (e) {
    var wrapper = document.getElementById ("wrapper");
        title = document.querySelector ("#title span"),
        notice = document.querySelector ("#notice span"),
        qualities = document.getElementById ("qualities");
    
    /* Add animation classes */
    title.classList.add ("quickFadeLeft");
    notice.classList.add ("quickFadeLeft");
    qualities.classList.add ("quickFadeDown");
    
    /* Update messages and add loading icon */
    setTimeout (function () {
        updateElement ("#title span", {content: "Launching Livestreamer"});
        updateElement ("#notice span", {content: "Launching " + e.target.dataset.quality  + " stream..."});
        buildElement ({
            append: wrapper,
            attribs: {
                id: "loading",
                class: ["loading", "quickBounce"]
            },
            content: buildElement ({
                type: "img",
                attribs: {
                    src: "../img/loading.svg",
                },
            }),
        });
        wrapper.removeChild (qualities);
    }, 300);
    /* Remove classes and reduce clutter in DOM */
    setTimeout (function () {
        title.classList.remove ("quickFadeLeft");
        notice.classList.remove ("quickFadeLeft");
        qualities.classList.remove ("quickFadeDown");
    }, 600);
}




















buildElement ({
    append: document.body,
    attribs: {
        id: "wrapper",
        class: "group"
    },
    content: [
        buildElement ({
            attribs: {
                id: "title",
                class: ["title", "group"],
            },
            content: buildElement ({
                type: "span",
                content: "Quality"
            })
        }),
        buildElement ({
            attribs: {
                id: "notice",
                class: ["notice", "group"],
            },
            content: buildElement ({
                type: "span",
                content: "Select stream quality"
            })
        }),
        buildElement ({
            attribs: {
                id: "qualities",
                class: ["list", "smooth", "group"],
            },
            empty: true,
            content: [
                buildElement ({
                    attribs: {
                        class: ["block"],
                        dataset: {
                            quality: "1080p"
                        }
                    },
                    content: "1080p"
                }),
                buildElement ({
                    attribs: {
                        class: ["block"],
                        dataset: {
                            quality: "720p"
                        }
                    },
                    content: "720p"
                }),
                buildElement ({
                    attribs: {
                        class: ["block"],
                        dataset: {
                            quality: "480p"
                        }
                    },
                    content: "480p"
                }),
                buildElement ({
                    attribs: {
                        class: ["block"],
                        dataset: {
                            quality: "360p"
                        }
                    },
                    content: "360p"
                })
            ]
        })
    ]
});

// Emit to main.js
var qualities = document.querySelectorAll ("#qualities .block");
// For each add click event
for (var i = 0; i < qualities.length; i++) {
    qualities[i].addEventListener("click", launchStreamer, false);
}











